starcluster.commands.ebsimage.CmdEbsImage

Package starcluster :: Package commands :: Module ebsimage :: Class CmdEbsImage |
[hide private]
[frames] | no frames]

# Class CmdEbsImage

source code

    ebsimage [options] <instance-id> <image_name>

    Create a new EBS image (AMI) from a running EC2 instance

    Example:

        $ starcluster ebsimage i-999999 my-new-image-ebs

    NOTE: It should now be safe to create an image from an instance launched by
    StarCluster. If you have issues please submit a bug report to the mailing
    list.

Instance Methods | [hide private]
addopts(self, parser) | source code
cancel_command(self, signum, frame) Exits program with return value of 1 | source code
execute(self, args) | source code
Inherited from `completers.InstanceCompleter` (private): `_completer` Inherited from `base.CmdBase`: `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_build_dict`, `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| names = ``[``'``ebsimage``'``,` `'``eimg``'``]``
| image_name = `None` hash(x)
| is_ebs_backed = `None` hash(x)
Inherited from `completers.InstanceCompleter`: `show_dns_names` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cfg`, `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `completers.Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`

Method Details | [hide private]

### addopts(self, parser) | source code
Overrides: base.CmdBase.addopts

### cancel_command(self, signum, frame) | source code
Exits program with return value of 1 Overrides: base.CmdBase.cancel_command (inherited documentation)